#!/bin/bash
# Modify/add the following parameters as needed 

#SBATCH -J spatialwmh
#SBATCH -t 22:00:00
#SBATCH --output=spatialwmh_%A_%a.out
#SBATCH --error=spatialwmh_%A_%a.err
#SBATCH --nodes=1
#SBATCH --ntasks=1
#SBATCH --tasks-per-node=1
#SBATCH --cpus-per-task=4
#SBATCH --mem-per-cpu=2500 #following https://www.mail-archive.com/freesurfer@nmr.mgh.harvard.edu/msg57788.html


# This is a script to run 
# FLAIR to T1 registration using FreeSurfer's bbregister
# Bullseye WM segmentation,
# extraction of 36 (Bullseye regions) + 5 (corpus callosum) spatial WMH volumes and
# extraction of TIV from FreeSurfer.



source ./array
sj_id=${FILES[$SLURM_ARRAY_TASK_ID]}

#sj_id=$5
PATH_SCRIPT=$1
PATH_OUT=$2
PATH_FREESURFER=$3
PATH_LESION=$4

###################################################################################################
#####										              #####
#####					PATHS THAT MUST BE CHANGED			      #####
#####											      #####
###################################################################################################				        

## Load FreeSurfer & Conda environment
#module load freesurfer
#module load conda

#conda activate spatialwmh

# File patterns to get native FLAIR/WMH maps for each subjct:	               
FLAIR=${PATH_LESION}/${sj_id}/FLAIR_intensity_normed.nii.gz #exact file name of wmh probability map
LESION=${PATH_LESION}/${sj_id}/predictedWMH.nii.gz #exact name of FLAIR/T2 image used for registration
  

###################################################################################################
# Set FreeSurfer SUBJECTS_DIR directory
export SUBJECTS_DIR=$PATH_FREESURFER

###################################################################################################
# Run Bullseye WM segmentation and WMH calculation
#mri_aparc2aseg --s ${sj_id} --annot lobes --labelwm --rip-unknown --hypo-as-wm --o lobes+aseg.nii.gz

python $PATH_SCRIPT/python/run_bullseye_WMH_segmentation.py ${sj_id} $PATH_OUT $PATH_FREESURFER $FLAIR $LESION

###################################################################################################
# Copy EstimatedTotalIntraCranialVolume into results file
cat $PATH_FREESURFER/${sj_id}/stats/aseg.stats | grep EstimatedTotalIntraCranialVol |  awk -F, '{ print $4 }' >> $PATH_OUT/${sj_id}/res_sum.txt
