from __future__ import division

import nipype.pipeline.engine as pe
import nipype.interfaces.utility as util
from nipype.interfaces.freesurfer import ApplyVolTransform, BBRegister
from nipype.interfaces.fsl import ImageStats

from nipype import IdentityInterface, DataSink

# from .utils import *
from utils import *

import os

def create_flairreg_pipeline():

    flairreg = pe.Workflow(name='flairreg_pipeline')
   
    inputnode = pe.Node(interface=IdentityInterface(fields=['subject_id', 'FLAIR', 'LESION']), name='inputnode')
    
    bbreg = pe.Node(BBRegister(contrast_type='t2',
                               out_fsl_file='flair2anat.mat',
                               out_reg_file='flair2anat.dat',
                               registered_file='flair2anat_bbreg.nii.gz',
                               ),
                               name='bbregister')

    # apply transform to lesionmap
    applyreg = pe.Node(ApplyVolTransform(), name="applyreg")
    applyreg.inputs.fs_target=True


    # outputnode
    outputnode = pe.Node(IdentityInterface(fields=[
        'lesion2anat', "flair2anat" ]),
        name='outputnode')


    ##### CONNECTIONS #####

    
    flairreg.connect(inputnode     , 'FLAIR',         bbreg, 'source_file')
    flairreg.connect(inputnode     , 'subject_id',         bbreg, 'subject_id')
    flairreg.connect(bbreg     , 'out_reg_file',         applyreg, 'reg_file')
    flairreg.connect(inputnode     , 'LESION',         applyreg, 'source_file')
    flairreg.connect(applyreg     , 'transformed_file',         outputnode,  'lesion2anat') 
    flairreg.connect(bbreg     , 'registered_file',         outputnode,  'flair2anat') 

    return(flairreg)
